<?php
namespace Teknisa\PLA\Modules\Cardapio\Services;

use Doctrine\ORM\EntityManager;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Teknisa\GER\Utilities\Environment;
use Zeedhi\Framework\DataSource\FilterCriteria;

class Pla00150AtualizarDataDeReferenciaParaCustosService {

    protected $parameterBagColumns = array();
    protected $environment;
    protected $entityManager;
    protected $dataSourceManager;
    protected $novoCodigo;

    const FILIAIS = 'filial_operador_grupfili';
    const SERVICO = 'servico';
    const CARDAMES = 'cardames';
    const VERIFICADATAPROC = 'pla00150_verifica_data_proc';
    const AUTGRUPOP = 'autgrupop';

    public function __construct(Environment $environment, $entityManager, $dataSourceManager, $novoCodigo) {
        $this->environment = $environment;
        $this->entityManager = $entityManager;
        $this->dataSourceManager = $dataSourceManager;
        $this->novoCodigo = $novoCodigo;
    }

    public function getFiliais($cdgrupfili, $cdoperador, $nrorg) {
        $filterCriteria = new FilterCriteria(self::FILIAIS);
        $filterCriteria->addCondition('CDGRUPFILI', $cdgrupfili);
        $filterCriteria->addCondition('CDOPERADOR', $cdoperador);
        $filterCriteria->addCondition('NRORG', $nrorg);
        return $filterCriteria;
    }

    public function getServicos($cdfilial, $idtiposerv, $nrorg) {
        $filterCriteria = new FilterCriteria(self::SERVICO);
        $filterCriteria->addCondition('CDFILIAL', 'IN', $cdfilial);
        $filterCriteria->addCondition('IDTIPOSERV', $idtiposerv);
        $filterCriteria->addCondition('NRORG', $nrorg);
        return $filterCriteria;
    }

    public function getCardames($cdfilial, $cdservfili, $dtmescardapio, $nrorg) {
        $cardames = $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Cardames');
        return $cardames->findOneBy(array("cdfilial" => $cdfilial, "cdservfili" => $cdservfili, "dtmescardapio" => $dtmescardapio, "nrorg" => $nrorg));
    }

    public function verificaDataProc($cdfilial, $data, $nrorg) {
        $filterCriteria = new FilterCriteria(self::VERIFICADATAPROC);
        $filterCriteria->addCondition('CDFILIAL', $cdfilial);
        $filterCriteria->addCondition('DATA', $data);
        $filterCriteria->addCondition('NRORG', $nrorg);
        return $filterCriteria;
    }

    public function getAutgrupop($idautgrupop, $nrorg) {
        $autgrupop = $this->entityManager->getRepository('\Producao\Entities\Autgrupop')->findOneBy(array("idautgrupop" => $idautgrupop, "nrorg" => $nrorg));
        if (empty($autgrupop)) {
            $cdgrupoper = null;
        } else {
            $cdgrupoper = $autgrupop->getCdgrupoper();
        }
        return $cdgrupoper;
    }

    public function getProcedure() {
        $query = $this->entityManager->getConnection()->prepare(
            "SELECT OWNER FROM ALL_OBJECTS WHERE OBJECT_TYPE = 'PROCEDURE' AND UPPER(OBJECT_NAME) = 'GRAVAPRECUSTO'"
        );
        $query->execute();
        $dataSet = $query->fetchAll();
        return $dataSet;
    }

    public function GRAVAPRECUSTO($dtinicial, $dtfinal, $codtipocusto, $codprodinicial, $codprodfinal, $dtrefpesquisa, $cdfilial, $servicos) {
        $connection = $this->entityManager->getConnection();
        $procedure = new StoredProcedure($connection, 'GRAVAPRECUSTO');
        $procedure->addParam(new Param('pDtInicial', Param::PARAM_INPUT, $dtinicial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('pDtFinal', Param::PARAM_INPUT, $dtfinal, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('pCodTipoCusto', Param::PARAM_INPUT, $codtipocusto, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('pCodProdInicial', Param::PARAM_INPUT, $codprodinicial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('pCodProdFinal', Param::PARAM_INPUT, $codprodfinal, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('pDtRefPesquisa', Param::PARAM_INPUT, $dtrefpesquisa, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('pCdFilial', Param::PARAM_INPUT, $cdfilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('PSERVICOS', Param::PARAM_INPUT, $servicos, Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
}